@@ -50,7 +50,7 @@ __END__
 
 =head1 NAME
 
-HTTP::Engine::Middleware::MethodOverride - documentation is TODO
+HTTP::Engine::Middleware::MethodOverride - simulate HTTP methods by query parameter
 
 =head1 SYNOPSIS
 
@@ -63,4 +63,12 @@ HTTP::Engine::Middleware::MethodOverride - documentation is TODO
         }
     )->run();
 
+=head1 DESCRIPTION
+
+This module simulates the some minor HTTP methods by the query parameter(ex. DELETE, PUT).
+
+=head1 AUTHORS
+
+dann
+
 =cut
